AutoExpResult class

Constructors

AutoExpResult({required double error, required double shutter, required double analogGain, required double redGain, required double greenGain, required double blueGain, required Brightness brightness})

Properties

analogGain → double
final
blueGain → double
final
brightness → Brightness
final
error → double
final
greenGain → double
final
hashCode → int
The hash code for this object.
no setterinherited
redGain → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shutter → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited