Brightness class

Constructors

Brightness({required double centerWeightedAverage, required double scene, required Matrix matrix, required Spot spot})

Properties

centerWeightedAverage → double
final
hashCode → int
The hash code for this object.
no setterinherited
matrix → Matrix
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scene → double
final
spot → Spot
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited