RxClick class
Click data stream, returns the type of Click detected
Properties
Methods
-
attach(
Stream< List< dataResponse) → Stream<int> >ClickType> - Attach this RxClick to the device's dataResponse characteristic stream.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited