IMUData class

Constructors

IMUData({required (double, double, double) compass, required (double, double, double) accel, IMURawData? raw})

Properties

accel → (double, double, double)
final
compass → (double, double, double)
final
hashCode → int
The hash code for this object.
no setterinherited
pitch → double
no setter
raw → IMURawData?
final
roll → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited