SensorBuffer class

Buffer class to allow us to provide a smoothed moving average of samples

Constructors

SensorBuffer(int maxSize)

Properties

average → (double, double, double)
no setter
hashCode → int
The hash code for this object.
no setterinherited
maxSize → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add((double, double, double) value) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited