MeteringData class

Constructors

MeteringData({required int spotR, required int spotG, required int spotB, required int matrixR, required int matrixG, required int matrixB})

Properties

hashCode → int
The hash code for this object.
no setterinherited
matrixB → int
final
matrixG → int
final
matrixR → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spotB → int
final
spotG → int
final
spotR → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited