RxMeteringData class

Receive handler for metering data from the camera sensor

Constructors

RxMeteringData({int meteringFlag = 0x12})

Properties

hashCode → int
The hash code for this object.
no setterinherited
meteringFlag → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

attach(Stream<List<int>> dataResponse) → Stream<MeteringData>
Attach this RxMeteringData to the Frame's dataResponse characteristic stream.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited