tx/text_page library

Classes

CircularTextLayout
A circular text layout, ideal for the Halo device. Text is constrained within a circle inscribed in the defined width/height.
PageData
Represents a single, measured page of text that is ready to be rasterized into sprites.
RectangularTextLayout
A standard rectangular text layout for the Frame device.
TextLayout
Abstract base class for defining the geometry of a text layout area. This allows for different shapes like rectangles and circles.
TxTextPage
Manages the process of laying out and rasterizing text into pages (TxSpriteBlocks). It works with any TextLayout to support different display shapes.