hasMoreText property
bool
get
hasMoreText
Returns true if there is more text to be laid out.
Implementation
bool get hasMoreText => _remainingText.isNotEmpty;
Returns true if there is more text to be laid out.
bool get hasMoreText => _remainingText.isNotEmpty;