remainingText property
String
get
remainingText
The portion of the text that has not yet been processed into a page.
Implementation
String get remainingText => _remainingText;
The portion of the text that has not yet been processed into a page.
String get remainingText => _remainingText;