RxClick class

Click data stream, returns the type of Click detected

Constructors

RxClick({int clickFlag = 0x0B})

Properties

clickFlag int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attach(Stream<List<int>> dataResponse) Stream<ClickType>
Attach this RxClick to the device's dataResponse characteristic stream.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited