RectangularTextLayout class
A standard rectangular text layout for the Frame device.
- Inheritance
-
- Object
- TextLayout
- RectangularTextLayout
Constructors
Properties
- fontFamily → String?
-
finalinherited
- fontSize → int
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startY → double
-
The starting Y coordinate for laying out text.
no setterinherited
- textAlign → TextAlign
-
finalinherited
- width → int
-
finalinherited
Methods
-
getLineLayout(
double lineY, double lineHeight) → ({int width, int xOffset})? -
Gets the layout parameters (width and x-offset) for a line at a specific Y position.
Returns null if the line is outside the displayable area.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited