TextLayout class abstract
Abstract base class for defining the geometry of a text layout area. This allows for different shapes like rectangles and circles.
- Implementers
Constructors
Properties
- fontFamily → String?
-
final
- fontSize → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startY → double
-
The starting Y coordinate for laying out text.
no setter
- textAlign → TextAlign
-
final
- width → int
-
final
Methods
-
getLineLayout(
double lineY, double lineHeight) → ({int width, int xOffset})? - Gets the layout parameters (width and x-offset) for a line at a specific Y position. Returns null if the line is outside the displayable area.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited